{
    "$graph": [
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "label": "output of infernal's cmscan or cmsearch",
                    "id": "#main/table_hits"
                }
            ],
            "steps": [
                {
                    "run": "#extract-coords-from-cmscan.cwl",
                    "in": [
                        {
                            "source": "#main/grep/SSUs",
                            "id": "#main/extract_coords/infernal_matches"
                        }
                    ],
                    "out": [
                        "#main/extract_coords/matched_seqs_with_coords"
                    ],
                    "id": "#main/extract_coords"
                },
                {
                    "run": "#pull-SSUs.cwl",
                    "in": [
                        {
                            "source": "#main/table_hits",
                            "id": "#main/grep/hits"
                        }
                    ],
                    "out": [
                        "#main/grep/SSUs"
                    ],
                    "id": "#main/grep"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/extract_coords/matched_seqs_with_coords",
                    "id": "#main/SSU_coordinates"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "label": "output from infernal cmscan or cmsearch",
                    "type": "File",
                    "streamable": true,
                    "id": "#extract-coords-from-cmscan.cwl/infernal_matches"
                }
            ],
            "baseCommand": "awk",
            "stdout": "matched_seqs_with_coords",
            "arguments": [
                "{print $4\"-\"$3\"/\"$10\"-\"$11\" \"$10\" \"$11\" \"$4}",
                "$(inputs.infernal_matches.path)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract-coords-from-cmscan.cwl/matched_seqs_with_coords",
                    "outputBinding": {
                        "glob": "matched_seqs_with_coords"
                    }
                }
            ],
            "doc": "The awk script takes the output of Infernal's cm{scan,search} fmt=2 mode and\nmakes it suitable for use by esl-sfetch, a sequence selector\n\nReading the user's guide for Infernal, Version 1.1.2; July 2016\nhttp://eddylab.org/infernal/Userguide.pdf#page=60 we see that\nthe relevant fields in the cmscan output are:\n(fmt2 column number: explanation)\n3: The accession of the target sequence or profile, or \u2019-\u2019 if none\n4: The name of the query sequence or profile \n10: The start of the alignment of this hit with respect to the\n    sequence, numbered 1..L for a sequence of L residues.\n11: The end of the alignment of this hit with respect to the sequence,\n    numbered 1..L for a sequence of L residues\n\nLikewise the format esl-sfetch wants is: <newname> <from> <to> <source seqname>\n\nPutting it all together we see that the newname (which esl-sfetch with\noutput using) is a concatenation of the original name, the sequence\nnumber, and the coordinates.\n",
            "id": "#extract-coords-from-cmscan.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#pull-SSUs.cwl/hits"
                }
            ],
            "baseCommand": [
                "grep",
                "SSU"
            ],
            "stdout": "SSUs",
            "arguments": [
                "$(inputs.hits.path)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#pull-SSUs.cwl/SSUs",
                    "outputBinding": {
                        "glob": "SSUs"
                    }
                }
            ],
            "id": "#pull-SSUs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
